Reports which real datasets can be redistributed with the package and records the status of the other biological studies used by the publication scripts.
Examples
available_spatial_benchmarks()
#> dataset included observations classes scenarios
#> 1 dlpfc TRUE 47329 7 45
#> 2 merfish FALSE 28317 8 45
#> 3 crc TRUE 194541 19 60
#> license
#> 1 Artistic-2.0 (spatialLIBD data package)
#> 2 CC0 raw Dryad data; no explicit license for derived BASS domain labels
#> 3 CC BY 4.0 (10x Genomics source and author-derived annotations)
#> source
#> 1 https://bioconductor.org/packages/spatialLIBD
#> 2 https://doi.org/10.5061/dryad.8t8s248
#> 3 https://www.10xgenomics.com/datasets/visium-hd-cytassist-gene-expression-libraries-of-human-crc-v4
#> note
#> 1 Coordinates, layer labels, and frozen corruption inputs are bundled.
#> 2 Use the publication script with a local processed annotation file.
#> 3 Coordinates, 19 WSI annotation labels, and deterministic corruption recipes are bundled; counts and tissue imagery are excluded.